##
##  klish.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2021 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         klish
Summary:      Command Line Interface Shell
URL:          http://klish.libcode.org/
Vendor:       Serj Kalichev, Graeme McKerrell et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        PLUS
Group:        Shell
License:      GPL
Version:      2.2.4
Release:      20211015

#   list of sources
Source0:      http://libcode.org/attachments/download/83/klish-%{version}.tar.xz
Source1:      rc.klish
Source2:      klish.xml
Patch0:       klish.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  pcre, expat
PreReq:       pcre, expat

%description
    Klish is a framework for implementing a CISCO-like Command-Line
    Interface (CLI) on a UNIX systems. It is configurable by XML files.
    The KLISH stands for "Kommand Line Interface Shell".

%track
    prog klish = {
        version   = %{version}
        url       = http://libcode.org/projects/klish/files
        regex     = klish-(__VER__)\.tar\.xz
    }

%prep
    %setup -q
    %patch -p0

%build
    #   configure program
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    LIBS="-lpcreposix -lpcre" \
    ./configure \
        --prefix=%{l_prefix} \
        --includedir=%{l_prefix}/include/klish \
        --libdir=%{l_prefix}/lib/klish \
        --with-libexpat=%{l_prefix} \
        --disable-shared

    #   build program
    %{l_make} %{l_mflags -O}

%install
    #   install program
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.klish} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install sample configuration
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/klish
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE klish.xml} $RPM_BUILD_ROOT%{l_prefix}/etc/klish/

    #   create additional run-time directory
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/klish

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/klish/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/klish'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} klish status 2>/dev/null`
    [ ".$klish_active" = .yes ] && %{l_rc} klish restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} klish stop 2>/dev/null
    rm -f $RPM_INSTALL_PREFIX/var/klish/* >/dev/null 2>&1 || true
    exit 0

